@@ -1,5 +1,6 @@
 import fire
 from .namespaces import MakeNamespace, CacheNamespace
+from .Commands import InitCommand
 
 
 class HomaCommand:
@@ -7,6 +8,9 @@ class HomaCommand:
         self.make = MakeNamespace()
         self.cache = CacheNamespace()
 
+    def init(self):
+        InitCommand.run()
+
 
 def main():
     fire.Fire(HomaCommand)
