@@ -1,11 +1,11 @@
 import torch
 from .modules import ResnetModule
-from .ClassificationModel import ClassificationModel
+from .Classifier import Classifier
 from .concerns import Trainable, ReportsMetrics
 from ..device import get_device
 
 
-class Resnet(ClassificationModel, Trainable, ReportsMetrics):
+class Resnet(Classifier, Trainable, ReportsMetrics):
     def __init__(self, num_classes: int, lr: float = 0.001):
         super().__init__()
         self.network = ResnetModule(num_classes).to(get_device())
